from .end_child_poverty_act import (
    create_end_child_poverty_act_reform,
    end_child_poverty_act,
)
from .economic_dignity_for_all_agenda import (
    end_child_poverty_act as edaa_end_child_poverty_act,
    create_end_child_poverty_act_reform as create_edaa_end_child_poverty_act_reform,
)
