"""
This makes the function create_tax_employer_payroll_reform available for
use without needing to specify the full module path.
i.e., we can just call:
from policyengine_us.reforms.tax_employer_payroll import create_tax_employer_payroll_reform
instead of:
from policyengine_us.reforms.tax_employer_payroll.tax_employer_payroll import create_tax_employer_payroll_reform
"""

from .tax_employer_social_security_tax import (
    create_tax_employer_social_security_tax_reform,
)

from .tax_employer_medicare_tax import (
    create_tax_employer_medicare_tax_reform,
)

from .tax_employer_payroll_tax import (
    create_tax_employer_payroll_tax_reform,
)
from .non_refundable_ss_credit import (
    create_non_refundable_ss_credit_reform,
)
from .senior_deduction_extension import (
    create_senior_deduction_extension_reform,
)
